@@ -4,21 +4,17 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.4/15.4.4/15.4.4.17/15.4.4.17-1-12.js
- * @description Array.prototype.some applied to RegExp object
+ * @path ch15/15.2/15.2.3/15.2.3.8/15.2.3.8-1-1.js
+ * @description Object.seal throws TypeError if type of first param is undefined
  */
 
 
 function testcase() {
-        function callbackfn(val, idx, obj) {
-            return obj instanceof RegExp;
+        try {
+            Object.seal(undefined);
+            return false;
+        } catch (e) {
+            return e instanceof TypeError;
         }
-
-        var obj = new RegExp();
-        obj.length = 2;
-        obj[0] = 11;
-        obj[1] = 9;
-
-        return Array.prototype.some.call(obj, callbackfn);
     }
 runTestCase(testcase);
